@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.17
+# Version   : 0.1.18
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -484,7 +484,7 @@ class AFM:
         '''
         self.approach = np.zeros([self.samps_line, len(self.filelist)])
         self.retract = np.zeros([self.samps_line, len(self.filelist)])
-        self.z_position = np.zeros([self.samps_line, len(self.filelist)])
+        self.z_position = np.zeros([self.samps_line * 2, len(self.filelist)])
 
         i = 0
         
